Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1519)

Unified Diff: third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp

Issue 2855843002: Reland "Sync requestFullscreen() and exitFullscreen() algorithms with the spec" (Closed)
Patch Set: Reland "Sync requestFullscreen() and exitFullscreen() algorithms with the spec" Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
diff --git a/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp b/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
index 3cf40d8966459e76380f3ba08e40e09e81502576..6e5a751be689a2fde02ea05b6824fbc77ab14cd5 100644
--- a/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
+++ b/third_party/WebKit/Source/web/WebRemoteFrameImpl.cpp
@@ -493,24 +493,21 @@ void WebRemoteFrameImpl::WillEnterFullscreen() {
HTMLFrameOwnerElement* owner_element =
ToHTMLFrameOwnerElement(GetFrame()->Owner());
- // Call requestFullscreen() on |ownerElement| to make it the provisional
- // fullscreen element in FullscreenController, and to prepare
- // fullscreenchange events that will need to fire on it and its (local)
- // ancestors. The events will be triggered if/when fullscreen is entered.
+ // Call |requestFullscreen()| on |ownerElement| to make it the pending
+ // fullscreen element in anticipation of the coming |didEnterFullscreen()|
+ // call.
//
// Passing |forCrossProcessAncestor| to requestFullscreen is necessary
// because:
// - |ownerElement| will need :-webkit-full-screen-ancestor style in
// addition to :-webkit-full-screen.
// - there's no need to resend the ToggleFullscreen IPC to the browser
// process.
//
// TODO(alexmos): currently, this assumes prefixed requests, but in the
// future, this should plumb in information about which request type
// (prefixed or unprefixed) to use for firing fullscreen events.
- Fullscreen::RequestFullscreen(*owner_element,
- Fullscreen::RequestType::kPrefixed,
- true /* forCrossProcessAncestor */);
+ Fullscreen::RequestFullscreen(
+ *owner_element,
+ Fullscreen::RequestType::kPrefixedForCrossProcessDescendant);
}
void WebRemoteFrameImpl::SetHasReceivedUserGesture() {
« no previous file with comments | « third_party/WebKit/Source/web/WebPluginContainerImpl.cpp ('k') | third_party/WebKit/Source/web/WebViewImpl.h » ('j') | no next file with comments »
@@ -493,24 +493,21 @@ void WebRemoteFrameImpl::WillEnterFullscreen() {
//
- // Passing |forCrossProcessAncestor| to requestFullscreen is necessary
- // because:
- // - |ownerElement| will need :-webkit-full-screen-ancestor style in
- // addition to :-webkit-full-screen.
- // - there's no need to resend the ToggleFullscreen IPC to the browser
- // process.
+ // PrefixedForCrossProcessDescendant is necessary because:
+ // - The fullscreen element ready check and other checks should be bypassed.
+ // - |ownerElement| will need :-webkit-full-screen-ancestor style in addition
+ // to :-webkit-full-screen.
//
// TODO(alexmos): currently, this assumes prefixed requests, but in the

Powered by Google App Engine
This is Rietveld 408576698